@@ -193,7 +193,7 @@ class Worker:
         job.complete(output["result"])
         self.jobs_completed += 1
       if "error" in output:
-        print(output["error"])
+        print(output["error"], flush=True)
         job.error(output["error"])
         self.jobs_failed += 1
         self.last_error_message = output["error"] if isinstance(output["error"], dict) else dict(message=output["error"], trace="")
